package com.example.takeawaysystemserver.util;

import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.*;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * @author 慕华
 * @date 2023/9/29
 * @Version 1.0
 * @description
 */
@Component
public class TimeUtil {

    /**
     * 获取当前毫秒转int
     */
    public static Integer getCurTimestamp() {
        long l = System.currentTimeMillis();
        return (int) (l / 1000);
    }

    /**
     * 获取今天0点的时间戳
     */
    public static Integer getCurDayZeroTimestamp(){
        Calendar cal = Calendar.getInstance();
        cal.set(Calendar.HOUR_OF_DAY, 0);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.MILLISECOND, 0);
        return (int) (cal.getTimeInMillis()/1000);
    }

    /**
     *获取 当月0点的时间戳
     */
    public static Integer getCurMonthZeroTimestamp(){
        Calendar cal = Calendar.getInstance();
        cal.set(cal.get(Calendar.YEAR),cal.get(Calendar.MONDAY), cal.get(Calendar.DAY_OF_MONTH), 0, 0,0);
        cal.set(Calendar.DAY_OF_MONTH,cal.getActualMinimum(Calendar.DAY_OF_MONTH));
        return (int) (cal.getTimeInMillis()/1000);
    }

    /**
     * 获取今年 0点的时间戳
     */
    public static Integer getCurYearZeroTimestamp(){

        Calendar c = Calendar.getInstance();
        c.add(Calendar.YEAR, 0);
        //设置为1号,当前日期既为本年第一天
        c.set(Calendar.DAY_OF_YEAR, 1);
        //将小时至0
        c.set(Calendar.HOUR_OF_DAY, 0);
        //将分钟至0
        c.set(Calendar.MINUTE, 0);
        //将秒至0
        c.set(Calendar.SECOND,0);
        //将毫秒至0
        c.set(Calendar.MILLISECOND, 0);
        // 获取今天第一天的时间戳
        return (int) (c.getTimeInMillis()/1000);
    }

    /**
     * 将时间转换为时间戳
     */
    public static String dateToStamp(String s) throws ParseException {
        String res;
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = simpleDateFormat.parse(s);
        long ts = date.getTime()/ 1000;
        res = String.valueOf(ts);
        return res;
    }

    /**
     * 将时间戳转换为时间
     */
    public static String stampToDate(Integer s){
        String res;
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        long lt = Long.valueOf(s);
        Date date = new Date(lt*1000);
        res = simpleDateFormat.format(date);
        return res;
    }
    /**
     * 获取本周周一的时间戳
     */
    public Long getSundayTime() {
        // 获取当前日期
        LocalDate currentDate = LocalDate.now();

        // 计算本周的周日日期
        LocalDate sundayDate = currentDate.with(DayOfWeek.MONDAY);

        // 将周日日期转换为 LocalDateTime，时间部分默认为 00:00
        LocalDateTime mondayTime = sundayDate.atStartOfDay();

        // 将 LocalDateTime 转换为 Instant
        Instant instant = mondayTime.toInstant(ZoneOffset.UTC);

        // 获取对应的 Unix 时间戳（毫秒级别）
        return instant.toEpochMilli();
    }

    public static Long getNowDate(){
        return System.currentTimeMillis();
    }

    public static String getNowYear(){
        Calendar calendar = Calendar.getInstance();
        String s = Integer.toString(calendar.get(Calendar.YEAR));
        return s.substring(s.length() - 2);
    }

    public static String getNowMonth(){
        Calendar calendar = Calendar.getInstance();
        return String.format("%02d", calendar.get(Calendar.MONTH) + 1);
    }

    public static String convertMonth(Long time){
        LocalDateTime dateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(time), ZoneId.systemDefault());
        return dateTime.getYear() + String.format("%02d",dateTime.getMonthValue());
    }

    public static String convertYear(Long time){
        LocalDateTime dateTime = LocalDateTime.ofInstant(Instant.ofEpochMilli(time), ZoneId.systemDefault());
        return dateTime.getYear() + "";
    }
}
